5ba0549a475bafee7d17a3fa9fc3a42d08cb1c11
tdreszer
  Fri May 3 17:06:11 2013 -0700
Clarified some comments based upon Angie's feedback.  Thanks.
diff --git src/inc/vcfBits.h src/inc/vcfBits.h
index 1a91fd3..477ac05 100644
--- src/inc/vcfBits.h
+++ src/inc/vcfBits.h
@@ -61,35 +61,35 @@
 // If unphasedBits, then vBits->unphased will contain a bitmap with 1s for all unphased genotypes.
 // NOTE: allocated from vcff pool, so closing file or flushing reusePool will invalidate this.
 
 Bits *vcfRecordHaploidBits(struct vcfFile *vcff, struct vcfRecord *record);
 // Returns array (1 bit per genotype) for each haploid genotype.
 // This is useful for interpreting chrX.
 
 int vBitsHaploidCount(struct variantBits *vBits);
 // Returns the number of subjects in the VCF dataset that are haploid at this location
 
 //#define vBitsSubjectChromCount(vBits) ((vBits)->genotypeSlots * (vBits)->haplotypeSlots)
 int vBitsSubjectChromCount(struct variantBits *vBits);
 // Returns the chromosomes in the VCF dataset that are covered at this location
 
 int vcfVariantBitsDropSparse(struct variantBits **vBitsList, int haploGenomeMin,
-                             boolean dropRefErrors);
+                             boolean dropRefMissing);
 // Drops vBits found in less than a minimum number of haplotype genomes.  Supplying 1 will
 // drop variants found in no haplotype genomes.  Declaring dropRefErrors will drop variants
 // in all haplotype genomes (variants where reference is wrong).
 // Returns count of vBits structure that were dropped.
 
 int vcfVariantBitsAlleleOccurs(struct variantBits *vBits, unsigned char alleleIx,
                                boolean homozygousOrHaploid);
@@ -61,35 +61,35 @@
 // Drops vBits found in less than a minimum number of haplotype genomes.  Supplying 1 will
-// drop variants found in no haplotype genomes.  Declaring dropRefErrors will drop variants
-// in all haplotype genomes (variants where reference is wrong).
-// Returns count of vBits structure that were dropped.
+// drop variants found in no haplotype genomes.  Declaring dropRefMissing will drop variants
+// in all haplotype genomes (variants where reference is not represented in dataset and
+// *might* be in error). Returns count of vBits structure that were dropped.
 
 int vcfVariantBitsAlleleOccurs(struct variantBits *vBits, unsigned char alleleIx,
 // Counts the number of times a particular allele occurs in the subjects*chroms covered.
 // If homozygousOrHaploid then the allele must occur in both chroms to be counted
 
 int vcfVariantBitsReferenceOccurs(struct vcfFile *vcff, struct variantBits *vBitsList,
                                   boolean homozygousOrHaploid);
 // For an entire list of vBits structs, counts the times the reference allele occurs.
 // If homozygousOrHaploid then the reference allele must occur in both chroms to be counted
 
 
 int vcfVariantMostPopularCmp(const void *va, const void *vb);
 // Compare to sort variantBits based upon how many genomes/chrom has the variant
 // This can be used to build haploBits in most populous order for tree building